@@ -56,6 +56,10 @@ class VCRConnectionMixin:
 
     def request(self, method, url, body=None, headers=None):
         '''Persist the request metadata in self._vcr_request'''
+        # see VCRConnectionMixin._restore_socket for the motivation here
+        if hasattr(self, 'sock'):
+            del self.sock
+
         self._vcr_request = Request(
             protocol=self._protocol,
             host=self.host,
@@ -161,12 +165,17 @@ class VCRConnectionMixin:
         '''Retrieve a the response'''
         # Check to see if the cassette has a response for this request. If so,
         # then return it
-        if self._vcr_request in self.cassette and  self.cassette.record_mode != "all" and self.cassette.rewound:
-            response = self.cassette.response_of(self._vcr_request)
+        if self._vcr_request in self.cassette and \
+                self.cassette.record_mode != "all" and \
+                self.cassette.rewound:
+            response = self.cassette.play_response(self._vcr_request)
             return VCRHTTPResponse(response)
         else:
             if self.cassette.write_protected:
-                raise Exception("cassette is write protected")
+                raise Exception(
+                    "Can't overwrite existing cassette in \
+                     your current record mode."
+                )
 
             # Otherwise, we should send the request, then get the response
             # and return it.
@@ -205,11 +214,6 @@ class VCRHTTPConnection(VCRConnectionMixin, HTTPConnection):
     _baseclass = HTTPConnection
     _protocol = 'http'
 
-    def __init__(self, *args, **kwargs):
-        HTTPConnection.__init__(self, *args, **kwargs)
-        # see VCRConnectionMixin._restore_socket for the motivation here
-        del self.sock
-
 
 class VCRHTTPSConnection(VCRConnectionMixin, HTTPSConnection):
     '''A Mocked class for HTTPS requests'''
@@ -223,5 +227,3 @@ class VCRHTTPSConnection(VCRConnectionMixin, HTTPSConnection):
         HTTPConnection.__init__(self, *args, **kwargs)
         self.key_file = kwargs.pop('key_file', None)
         self.cert_file = kwargs.pop('cert_file', None)
-        # see VCRConnectionMixin._restore_socket for the motivation here
-        del self.sock
